@@ -28,7 +28,6 @@ from .xpak import Xpak
 
 
 class force_unpacking(triggers.base):
-
     required_csets = ("new_cset",)
     priority = 5
     _hooks = ("sanity_check",)
@@ -132,8 +131,7 @@ class StackedXpakDict(DictMixin):
                 data = data_source(self.xpak.get("environment"), mutable=True)
                 if data is None:
                     raise KeyError(
-                        "environment.bz2 not found in xpak segment, "
-                        "malformed binpkg?"
+                        "environment.bz2 not found in xpak segment, malformed binpkg?"
                     )
             else:
                 data = data_source(
@@ -186,7 +184,6 @@ class StackedXpakDict(DictMixin):
 
 
 class StackedCache(StackedDict):
-
     __externally_mutable__ = True
 
     def __delitem__(self, key):
@@ -194,7 +191,6 @@ class StackedCache(StackedDict):
 
 
 class tree(prototype.tree):
-
     # yes, the period is required. no, do not try and remove it
     # (harring says it stays)
     extension = ".tbz2"
@@ -205,7 +201,7 @@ class tree(prototype.tree):
     cache_name = "Packages"
 
     pkgcore_config_type = ConfigHint(
-        {"location": "str", "repo_id": "str"}, typename="repo"
+        types={"location": "str", "repo_id": "str"}, typename="repo"
     )
 
     def __init__(self, location, repo_id=None, cache_version="0"):
@@ -242,10 +238,7 @@ class tree(prototype.tree):
     def __str__(self):
         return self.repo_id
 
-    def _get_categories(self, *optional_category):
-        # return if optional_category is passed... cause it's not yet supported
-        if optional_category:
-            return {}
+    def _get_categories(self):
         try:
             return tuple(x for x in listdir_dirs(self.base) if x.lower() != "all")
         except EnvironmentError as e:
