@@ -162,7 +162,6 @@ _Packages = namedtuple("_Packages", ("system", "profile"))
 
 
 class ProfileNode(metaclass=caching.WeakInstMeta):
-
     __inst_caching__ = True
     _repo_map = None
 
@@ -255,6 +254,8 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
                                     f"unknown repo {repo_id!r}"
                                 )
                                 continue
+                    else:
+                        location = repo_config.location
                     l.append(
                         (
                             abspath(pjoin(location, "profiles", profile_path)),
@@ -603,14 +604,13 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
 
 
 class EmptyRootNode(ProfileNode):
-
     __inst_caching__ = True
 
     parents = ()
     deprecated = None
-    pkg_use = (
-        masked_use
-    ) = stable_masked_use = forced_use = stable_forced_use = misc.ChunkedDataDict()
+    pkg_use = masked_use = stable_masked_use = forced_use = stable_forced_use = (
+        misc.ChunkedDataDict()
+    )
     forced_use.freeze()
     pkg_bashrc = ()
     pkg_use_force = pkg_use_mask = ImmutableDict()
@@ -618,7 +618,6 @@ class EmptyRootNode(ProfileNode):
 
 
 class ProfileStack:
-
     _node_kls = ProfileNode
 
     def __init__(self, profile):
@@ -639,15 +638,14 @@ class ProfileStack:
             for path, line, lineno in node.parent_paths:
                 try:
                     x = self._node_kls._autodetect_and_create(path)
-                except ProfileError as e:
+                except ProfileError as exc:
                     repo_id = node.repoconfig.repo_id
                     logger.error(
                         f"repo {repo_id!r}: '{self.name}/parent' (line {lineno}), "
-                        f"bad profile parent {line!r}: {e.error}"
+                        f"bad profile parent {line!r}: {exc.error}"
                     )
                     continue
-                for y in f(x):
-                    yield y
+                yield from f(x)
             yield node
 
         return tuple(f(self.node))
@@ -860,9 +858,8 @@ class ProfileStack:
 
 
 class OnDiskProfile(ProfileStack):
-
     pkgcore_config_type = ConfigHint(
-        {"basepath": "str", "profile": "str"},
+        types={"basepath": "str", "profile": "str"},
         required=("basepath", "profile"),
         typename="profile",
     )
@@ -916,7 +913,6 @@ class OnDiskProfile(ProfileStack):
 
 
 class UserProfileNode(ProfileNode):
-
     parent_node_kls = ProfileNode
 
     def __init__(self, path, parent_path):
@@ -933,9 +929,8 @@ class UserProfileNode(ProfileNode):
 
 
 class UserProfile(OnDiskProfile):
-
     pkgcore_config_type = ConfigHint(
-        {"user_path": "str", "parent_path": "str", "parent_profile": "str"},
+        types={"user_path": "str", "parent_path": "str", "parent_profile": "str"},
         required=("user_path", "parent_path", "parent_profile"),
         typename="profile",
     )
