@@ -40,7 +40,13 @@ class fetch_base:
         resumecmd = domain.settings.get("RESUMECOMMAND", fetchcmd)
         attempts = int(domain.settings.get("FETCH_ATTEMPTS", 10))
         self.fetcher = fetch_custom.fetcher(
-            self.distdir, fetchcmd, resumecmd, attempts=attempts
+            self.distdir,
+            fetchcmd,
+            resumecmd,
+            attempts=attempts,
+            PATH=os.environ["PATH"],
+            http_proxy=domain.get_settings_envvar("http_proxy", ""),
+            https_proxy=domain.get_settings_envvar("https_proxy", ""),
         )
 
     def fetch_all(self, observer):
@@ -83,7 +89,6 @@ class fetch_base:
 
 
 class operations(_operations_mod.base):
-
     _fetch_kls = fetch_base
 
     def __init__(
@@ -158,7 +163,6 @@ class operations(_operations_mod.base):
 
 
 class build_operations(operations):
-
     __required__ = frozenset(["build"])
 
     def _cmd_api_build(self, observer=None, failed=False, clean=True, **kwargs):
@@ -174,7 +178,6 @@ class build_operations(operations):
 
 
 class build_base(metaclass=ForcedDepends):
-
     stage_depends = {"finish": "start"}
 
     def __init__(self, domain, observer):
@@ -189,7 +192,6 @@ class build_base(metaclass=ForcedDepends):
 
 
 class build(build_base):
-
     stage_depends = {
         "setup": "start",
         "unpack": "setup",
@@ -251,7 +253,6 @@ class build(build_base):
 
 
 class install(build_base):
-
     stage_depends = {
         "preinst": "start",
         "postinst": "preinst",
@@ -279,7 +280,6 @@ class install(build_base):
 
 
 class uninstall(build_base):
-
     stage_depends = {
         "prerm": "start",
         "postrm": "prerm",
@@ -311,7 +311,6 @@ class uninstall(build_base):
 
 
 class replace(install, uninstall):
-
     stage_depends = {
         "finalize": "postinst",
         "postinst": "postrm",
@@ -327,7 +326,6 @@ class replace(install, uninstall):
 
 
 class empty_build_op(build_base):
-
     stage_depends = {}
 
     def __init__(self, pkg, observer=None, clean=False):
