@@ -9,7 +9,6 @@ from .installed import VersionedInstalled
 
 
 class EclassConsumerSet(VersionedInstalled):
-
     pkgcore_config_type = ConfigHint(
         typename="pkgset",
         types={"vdb": "refs:repo", "repos": "refs:repo", "eclasses": "list"},
@@ -26,7 +25,7 @@ class EclassConsumerSet(VersionedInstalled):
             if not pkgs:
                 # pkg is installed but no longer in any repo, just ignore it.
                 continue
-            assert len(pkgs) == 1, "I do not know what I am doing: %r" % (pkgs,)
+            assert len(pkgs) == 1, f"I do not know what I am doing: {pkgs}"
             pkg = pkgs[0]
             if self.eclasses.isdisjoint(pkg.data.get("_eclasses_", ())):
                 yield atom
