@@ -1,4 +1,5 @@
 """pkgcore plugins package."""
 
-from pkgcore.plugin import extend_path
+from ..plugin import extend_path
+
 extend_path(__path__, __name__)
