@@ -13,30 +13,26 @@ from . import multiplex, prototype, virtual
 
 
 class SimpleTree(prototype.tree):
-    """Fake, in-memory repository.
-
-    Args:
-        cpv_dict (dict): CPVs to populate the repo with
-        pkg_klass: class of packages in repo
-        livefs (bool): regular repo if False, vdb if True
-        frozen (bool): repo is modifiable if False, otherwise readonly
-        repo_id (str): repo ID
-    """
+    """in-memory repository used for testing or simple shims."""
 
     def __init__(
-        self, cpv_dict, pkg_klass=None, livefs=False, frozen=True, repo_id=None
+        self, cpv_dict, pkg_klass=VersionedCPV, livefs=False, frozen=True, repo_id=None
     ):
+        """
+        Args:
+            cpv_dict (dict): CPVs to populate the repo with
+            pkg_klass: class of packages in repo
+            livefs (bool): regular repo if False, vdb if True
+            frozen (bool): repo is modifiable if False, otherwise readonly
+            repo_id (str): repo ID
+        """
         self.cpv_dict = cpv_dict
-        if pkg_klass is None:
-            pkg_klass = VersionedCPV
         self.livefs = livefs
         self.repo_id = repo_id
         self.package_class = pkg_klass
         super().__init__(frozen=frozen)
 
-    def _get_categories(self, *arg):
-        if arg:
-            return ()
+    def _get_categories(self):
         return tuple(self.cpv_dict.keys())
 
     def _get_packages(self, category):
