@@ -11,21 +11,24 @@ def run(script_name):
     """Run a given script module."""
     try:
         from pkgcore.util.commandline import Tool
-        script_module = '.'.join(
-            os.path.realpath(__file__).split(os.path.sep)[-3:-1] +
-            [script_name.replace('-', '_')])
+
+        script_module = ".".join(
+            os.path.realpath(__file__).split(os.path.sep)[-3:-1]
+            + [script_name.replace("-", "_")]
+        )
         script = import_module(script_module)
     except ImportError as e:
-        sys.stderr.write(f'Failed importing: {e}!\n')
-        py_version = '.'.join(map(str, sys.version_info[:3]))
+        sys.stderr.write(f"Failed importing: {e}!\n")
+        py_version = ".".join(map(str, sys.version_info[:3]))
         sys.stderr.write(
-            'Verify that pkgcore and its deps are properly installed '
-            f'and/or PYTHONPATH is set correctly for python {py_version}.\n')
+            "Verify that pkgcore and its deps are properly installed "
+            f"and/or PYTHONPATH is set correctly for python {py_version}.\n"
+        )
         # show traceback in debug mode or for unhandled exceptions
-        if '--debug' in sys.argv[1:] or not all((e.__cause__, e.__context__)):
-            sys.stderr.write('\n')
+        if "--debug" in sys.argv[1:] or not all((e.__cause__, e.__context__)):
+            sys.stderr.write("\n")
             raise
-        sys.stderr.write('Add --debug to the commandline for a traceback.\n')
+        sys.stderr.write("Add --debug to the commandline for a traceback.\n")
         sys.exit(1)
 
     tool = Tool(script.argparser)
@@ -40,5 +43,5 @@ def main():
     run(os.path.basename(sys.argv[0]))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
