@@ -148,7 +148,7 @@ commandline.make_query(
     copy,
     nargs="+",
     dest="query",
-    help="packages matching any of these restrictions will be selected " "for copying",
+    help="packages matching any of these restrictions will be selected for copying",
 )
 copy_opts = copy.add_argument_group("subcommand options")
 copy_opts.add_argument(
@@ -201,8 +201,7 @@ def copy_main(options, out, err):
                     )
                 except OSError as oe:
                     err.write(
-                        f"failed accessing fs obj {fsobj!r}; {oe}\n"
-                        "aborting this copy"
+                        f"failed accessing fs obj {fsobj!r}; {oe}\naborting this copy"
                     )
                     failures = True
                     new_contents = None
@@ -496,12 +495,25 @@ eclass_opts = eclass.add_argument_group("subcommand options")
 eclass_opts.add_argument(
     "--dir", dest="output_dir", type=arghparse.create_dir, help="output directory"
 )
+eclass_opts.add_argument(
+    "-o",
+    "--output",
+    dest="output_format",
+    default="{eclass}.eclass.{format}",
+    help="output file name format",
+    docs="""
+        Output file name format. Defaults to ``{eclass}.eclass.{format}``. You
+        can use ``{eclass}`` and ``{format}`` placeholders to customize the
+        output file name. The filename can have path separator, for example:
+        ``{eclass}/{eclass}.eclass.{format}``.
+    """,
+)
 eclass_opts.add_argument(
     "-f",
     "--format",
     help="output format",
     default="man",
-    choices=("rst", "man", "html"),
+    choices=("rst", "man", "html", "devbook"),
 )
 eclass_opts.add_argument(
     "-r",
@@ -541,12 +553,22 @@ def _eclass_main(options, out, err):
 
     for path in options.eclasses:
         try:
-            with open(
-                pjoin(options.output_dir, f"{os.path.basename(path)}.{ext}"), "wt"
-            ) as f:
-                obj = EclassDoc(path)
+            filename = pjoin(
+                options.output_dir,
+                options.output_format.format(
+                    eclass=os.path.basename(path).removesuffix(".eclass"),
+                    format=ext,
+                ),
+            )
+            out.write("Compiling: ", path)
+            os.makedirs(os.path.dirname(filename), exist_ok=True)
+            with open(filename, "wt") as f:
+                obj = EclassDoc(path, sourced=True)
                 convert_func = getattr(obj, f"to_{options.format}")
                 f.write(convert_func())
+        except NotImplementedError as e:
+            err.write(f"{eclass.prog}: failed {path!r}: {e}")
+            raise
         except ValueError as e:
             # skip eclasses lacking eclassdoc support
             err.write(f"{eclass.prog}: skipping {path!r}: {e}")
