@@ -6,15 +6,15 @@ from . import base
 
 
 class git_syncer(base.VcsSyncer):
-
     binary = "git"
 
     supported_uris = (
         ("git://", 5),
         ("git+", 5),
+        ("git@", 5),
     )
 
-    supported_protocols = ("http://", "https://", "git://")
+    supported_protocols = ("http://", "https://", "git://", "git@")
     supported_exts = (".git",)
 
     @classmethod
