@@ -134,7 +134,6 @@ class NoDefaultConfigError(argparse.ArgumentError):
 
 
 class StoreConfigObject(argparse._StoreAction):
-
     default_priority = 20
 
     def __init__(self, *args, **kwargs):
@@ -198,7 +197,7 @@ class StoreConfigObject(argparse._StoreAction):
         )
 
     def _get_sections(self, config, namespace):
-        return getattr(config, self.config_type)
+        return getattr(config.objects, self.config_type)
 
     def _real_call(self, parser, namespace, values, option_string=None):
         config = getattr(namespace, "config", None)
@@ -227,7 +226,7 @@ class StoreConfigObject(argparse._StoreAction):
             )
         obj = config.get_default(config_type)
         if obj is None:
-            known_objs = sorted(getattr(config, config_type).keys())
+            known_objs = sorted(getattr(config.objects, config_type).keys())
             msg = f"config error: no default object of type {config_type!r} found.  "
             if not option_string:
                 msg += "Please fix your configuration."
@@ -291,8 +290,7 @@ class StoreRepoObject(StoreConfigObject):
     def __init__(self, *args, **kwargs):
         if "config_type" in kwargs:
             raise ValueError(
-                "StoreRepoObject: config_type keyword is redundant: got %s"
-                % (kwargs["config_type"],)
+                f"StoreRepoObject: config_type keyword is redundant: got {kwargs['config_type']}"
             )
 
         self.repo_type = kwargs.pop("repo_type", "all")
@@ -304,12 +302,9 @@ class StoreRepoObject(StoreConfigObject):
         if self.allow_aliases:
             unknown_aliases = self.allow_aliases.difference(self.valid_repo_types)
             if unknown_aliases:
+                es = pluralism(unknown_aliases, plural="es")
                 raise argparse.ArgumentTypeError(
-                    "unknown repo alias%s: %s"
-                    % (
-                        pluralism(unknown_aliases, plural="es"),
-                        ", ".join(unknown_aliases),
-                    )
+                    f"unknown repo alias{es}: {', '.join(unknown_aliases)}"
                 )
 
         if self.repo_type == "config":
@@ -381,17 +376,16 @@ class StoreRepoObject(StoreConfigObject):
 
 class DomainFromPath(StoreConfigObject):
     def __init__(self, *args, **kwargs):
-        kwargs["config_type"] = "domain"
-        super().__init__(*args, **kwargs)
+        super().__init__(*args, config_type="domain", **kwargs)
 
     def _load_obj(self, sections, requested_path):
         targets = list(find_domains_from_path(sections, requested_path))
         if not targets:
             raise ValueError(f"couldn't find domain at path {requested_path!r}")
         elif len(targets) != 1:
+            domains = ", ".join(repr(x[0]) for x in targets)
             raise ValueError(
-                "multiple domains claim root %r: domains %s"
-                % (requested_path, ", ".join(repr(x[0]) for x in targets))
+                f"multiple domains claim root {requested_path!r}: domains {domains}"
             )
         return targets[0][1]
 
@@ -423,8 +417,7 @@ class BooleanQuery(arghparse.DelayedValue):
 
         if converter is not None and not callable(converter):
             raise ValueError(
-                "converter either needs to be None, or a callable;"
-                f" got {converter!r}"
+                f"converter either needs to be None, or a callable; got {converter!r}"
             )
 
         self.converter = converter
@@ -535,9 +528,11 @@ def _mk_domain(parser, help=True):
         get_default=True,
         config_type="domain",
         action=StoreConfigObject,
-        help="custom pkgcore domain to use for this operation"
-        if help
-        else argparse.SUPPRESS,
+        help=(
+            "custom pkgcore domain to use for this operation"
+            if help
+            else argparse.SUPPRESS
+        ),
     )
 
 
@@ -554,7 +549,7 @@ class _ConfigArg(argparse._StoreAction):
     """Store given config path location or use the stub config when disabled."""
 
     def __call__(self, parser, namespace, value, option_string=None):
-        if value.lower() in {"false", "no", "n"}:
+        if value.lower() in ("false", "no", "n"):
             path = pjoin(const.DATA_PATH, "stubconfig")
         else:
             path = arghparse.existent_path(value)
@@ -581,9 +576,11 @@ class ArgumentParser(arghparse.ArgumentParser):
                     "--config",
                     action=_ConfigArg,
                     dest="config_path",
-                    help="use custom config or skip loading system config"
-                    if help
-                    else argparse.SUPPRESS,
+                    help=(
+                        "use custom config or skip loading system config"
+                        if help
+                        else argparse.SUPPRESS
+                    ),
                     docs="""
                         The path to a custom pkgcore config file or portage
                         config directory can be given to override loading the
