@@ -7,7 +7,6 @@ from snakeoil.osutils import normpath, pjoin
 
 
 class base:
-
     kls = None
 
     def make_obj(self, location="/tmp/foo", **kwds):
@@ -98,7 +97,6 @@ class base:
 
 
 class Test_fsFile(base):
-
     kls = fs.fsFile
 
     def test_init(self):
@@ -106,7 +104,8 @@ class Test_fsFile(base):
         o = self.make_obj(__file__)
         with open(__file__) as f:
             raw_data = f.read()
-        assert o.data.text_fileobj().read() == raw_data
+        with o.data.text_fileobj() as f:
+            assert f.read() == raw_data
 
         o = self.make_obj(
             "/bin/this-file-should-not-exist-nor-be-read", data=data_source(raw_data)
