@@ -6,8 +6,7 @@ from pkgcore.test.scripts.helpers import ArgParseMixin
 
 
 class FakeDomain:
-
-    pkgcore_config_type = ConfigHint({"repo": "ref:repo"}, typename="domain")
+    pkgcore_config_type = ConfigHint(types={"repo": "ref:repo"}, typename="domain")
 
     def __init__(self, repo):
         object.__init__(self)
@@ -37,7 +36,6 @@ domain_config = basics.HardCodedConfigSection(
 
 
 class TestCommandline(ArgParseMixin):
-
     _argparser = pebuild.argparser
 
     def test_parser(self):
