@@ -6,7 +6,6 @@ from pkgcore.sync.tar import tar_syncer
 
 
 class TestTarSyncer:
-
     def test_uri_parse(self):
         assert tar_syncer.parse_uri("tar+http://repo.tar.gz") == "http://repo.tar.gz"
 
@@ -19,7 +18,7 @@ class TestTarSyncer:
             tar_syncer.parse_uri("tar+https://repo.tar.foo")
 
         for ext in tar_syncer.supported_exts:
-            for proto in ('http', 'https'):
+            for proto in ("http", "https"):
                 for uri in (f"tar+{proto}://repo{ext}", f"{proto}://repo{ext}"):
                     o = tar_syncer("/tmp/foon", uri)
                     assert o.uri == f"{proto}://repo{ext}"
@@ -27,13 +26,13 @@ class TestTarSyncer:
 
 @pytest.mark_network
 class TestTarSyncerReal:
-
     def test_sync(self, tmp_path):
-        path = tmp_path / 'repo'
+        path = tmp_path / "repo"
         syncer = tar_syncer(
-            str(path), "https://github.com/pkgcore/pkgrepo/archive/master.tar.gz")
+            str(path), "https://github.com/pkgcore/pkgrepo/archive/master.tar.gz"
+        )
         assert syncer.sync()
-        layout_conf = os.path.join(path, 'metadata', 'layout.conf')
+        layout_conf = os.path.join(path, "metadata", "layout.conf")
         assert os.path.exists(layout_conf)
         stat = os.stat(layout_conf)
         # re-sync and verify that the repo didn't get replaced
